@@ -1,17 +1,17 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
-# $Id: elatom.py 439 2011-07-13 12:03:05Z maury $
+# $Id: elatom.py eliovir $
 #
-# Author : Olivier Maury
+# Author : Eliovir
 # Creation Date : 2009-04-24 12:49:49CEST
-# Last Revision : $Date: 2011-07-13 14:03:05 +0200 (mer. 13 juil. 2011) $
-# Revision : $Rev: 439 $
+# Last Revision : $Date: $
+# Revision : $Rev: $
 #
 # tested on WinXP with Python 3.2.1
 """
 Main file for Elatom, a podcast downloader for Python 3.
 """
-__revision__ = "$Rev: 439 $"
+__revision__ = "1.0.10"
 __author__ = "Eliovir"
 
 import codecs
@@ -23,6 +23,7 @@ from optparse import OptionGroup, OptionParser
 import os
 import platform
 import re
+import socket
 import string
 import sys
 import time
@@ -72,6 +73,14 @@ else:
     import curses
     CURSES_AVAILABLE = True
 
+try:
+    import notify2
+    import dbus.exceptions
+    NOTIFY_AVAILABLE = True
+except ImportError as error:
+    NOTIFY_AVAILABLE = False
+    print("IIII        To enable the notifications, install notify2 from https://pypi.python.org/pypi/notify2. `pip install notify2`.", file=sys.stderr)
+
 ###########
 #         #
 # Gettext #
@@ -110,7 +119,7 @@ else:
 #      #
 ########
 usage = _("usage: %prog [options]")
-parser = OptionParser(usage=usage)
+parser = OptionParser(usage=usage, version=__revision__)
 group_ui = OptionGroup(parser, _("Interface"),
                                 _("Interface for launching the application."))
 group_ui.add_option("-c", "--cli",
@@ -685,6 +694,8 @@ class FeedReader(threading.Thread):
             for info in results["files"]:
                 self._urls.append((info["id"], info["url"],
                                 info["pubDate"], info["title"]))
+        except socket.error as error:
+            self.log("Could not open socket: %s (%s : %s)" % (self._url, error.errno, error.strerror))
         except urllib.error.HTTPError as error:
             self.log("HTTP Error: %s %s" %
                     (self._url, HTTP_RESPONSES[error.code][0]))
@@ -867,7 +878,7 @@ class Elatom(threading.Thread):
                 return
 
         # stop the frontends
-        self._app.status(_("All files are downloaded.") + " " + _("Bye"), 1, 1)
+        self._app.status((n_("%d file has been downloaded.", "%d files have been downloaded.", file_nb) % file_nb) + " " + _("Bye"), 1, 1)
         time.sleep(2)
         self._app.stop()
 
@@ -1143,10 +1154,43 @@ class BaseApp:
     Abstract class for the interfaces.
     """
     _elatom = None
+    _notification = None
     def add_feed_info(self, name, total):
         raise NotImplementedError()
+    def notify(self, title, text, icon="notification-message-im"):
+        """
+        Communicate with the notifications server.
+
+        @type   title:  string
+        @param  title:  notification title
+        @type   text:   string
+        @parm   text:   notification text
+        @type   icon:   string
+        @param  icon:   icon name
+        """
+        if self._notification is None:
+            return
+        self._notification.update(title, text, icon)
+        self._notification.show()
     def set_elatom(self, elatom):
         self._elatom = elatom
+    def use_notification(self, use):
+        """
+        Enable the notification display.
+
+        @type   use:    boolean
+        @param  use:    action
+        """
+        try:
+            if use and notify2.init('Elatom'):
+                self._notification = notify2.Notification('title', 'text', 'icon')
+            else:
+                print("!!!! notify2 init failed")
+                self._notification = None
+        except dbus.exceptions.DBusException as error:
+            # org.freedesktop.DBus.Error.NotSupported:
+            # Unable to autolaunch a dbus-daemon without a $DISPLAY for X11
+            self._notification = None
     def start(self):
         raise NotImplementedError()
     def status(self, text, progress, total):
@@ -1263,6 +1307,7 @@ class QuietApp(BaseApp):
     def add_feed_info(self, name, total):
         pass
     def status(self, text, progress, total):
+        self.notify("Elatom", text)
         pass
     def start(self):
         pass
@@ -1284,8 +1329,10 @@ class TkApp(BaseApp):
         self.feed_infos = {}
         self.root = tkinter.Tk()
         # window title text
-        self.root.title("ElAtom")
+        self.root.title("Elatom")
         self.root.wm_title("Elatom")
+        self.root.client("Elatom")
+        self.root.wm_client("Elatom")
         # application icon
         iconpath = os.path.join(os.path.abspath(os.path.dirname(sys.argv[0])),
                                 "elatom.xbm")
@@ -1397,6 +1444,7 @@ class TkApp(BaseApp):
 
     def status(self, text, progress, total):
         self.vtext.set(text)
+        self.notify("Elatom", text)
         if total > 0:
             self._prog.set_max(total)
             self._prog.set_value(progress)
@@ -1693,6 +1741,7 @@ def main(options):
     else:
         Download.Start = True
         app = QuietApp()
+    app.use_notification(NOTIFY_AVAILABLE)
     elatom = Elatom(app)
     elatom.start()
     app.start()
